==> prokyon3_0.9.2.orig.tar.gz: prokyon3-0.9.2/src/gui_searcher.h <==
/***************************************************************************
                          gui_searcher.h  -  description
                             -------------------
    begin                : Thu May 3 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI_SEARCHER_H
#define GUI_SEARCHER_H

#include <qwidget.h>
#include <qframe.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qlineedit.h>

class GUI_Searcher : public QFrame  {
   Q_OBJECT
public: 
	GUI_Searcher(QWidget *parent=0, const char *name=0);

	void setConnectionState(bool state);
	
	~GUI_Searcher();

private:	
	QPushButton *button_search;
	QCheckBox *filenamecheck;
	QCheckBox *artistcheck;
	QCheckBox *titlecheck;
	QCheckBox *albumcheck;
	QCheckBox *commentcheck;

	QLineEdit *phrase;

	int defaults[5];

private slots:
	void slot_buttonSearch();
	void slot_buttonReset();
	void slot_buttonDefaults();
};

#endif

==> prokyon3_0.9.4.orig.tar.gz: prokyon3-0.9.4/src/gui_searcher.h <==
/***************************************************************************
                          gui_searcher.h  -  description
                             -------------------
    begin                : Thu May 3 2001
    copyright            : (C) 2001 by Holger Sattel
    email                : hsattel@rumms.uni-mannheim.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUI_SEARCHER_H
#define GUI_SEARCHER_H

#include <qwidget.h>
#include <qframe.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <qlineedit.h>

class GUI_Searcher : public QFrame  {
   Q_OBJECT
public: 
	GUI_Searcher(QWidget *parent=0, const char *name=0);
	~GUI_Searcher();

public slots:
    void slot_setConnectionState(bool state);

private:	
	QPushButton *button_search;
	QCheckBox *filenamecheck;
	QCheckBox *artistcheck;
	QCheckBox *titlecheck;
	QCheckBox *albumcheck;
	QCheckBox *commentcheck;
    QCheckBox *notescheck;

	QLineEdit *phrase;

	int defaults[6];

private slots:
	void slot_buttonSearch();
	void slot_buttonReset();
	void slot_buttonDefaults();
};

#endif
